# TorrentFile

## Version 0.1.0

### Fixed

    - Documentation updates and minor bug fixes

### Feature

    - Including web-seed urls to torrent file info during file creation

### Added

    - CLI argument for adding web-seed urls to torrent file

----------------

## Version 0.0.2

### Added

    - Full testing suite with 100% coverage

### Fixed/Improved

    - Rechecking procedure and output

----------------

## Version 0.0.1

    - New Project based off of torrentfile-legacy
